"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.AuthBasic = void 0;
const joi_1 = __importDefault(require("joi"));
const cm_libs_context_aware_error_1 = require("cm-libs-context-aware-error");
const auth_type_1 = require("./auth-type");
const auth_type_verify_1 = require("./auth-type-verify");
class AuthBasic {
    constructor(fnVerify) {
        this.fnVerify = fnVerify;
    }
    static init(fnVerify) {
        this.self = new AuthBasic(fnVerify);
    }
    async verifyIdToken(authToken) {
        const _verifiedIdToken = await this.fnVerify(authToken.info.authMetadata?.basic);
        const { error, value } = joi_1.default.object().keys(auth_type_verify_1.schemaVerifyIdToken).validate(_verifiedIdToken, { stripUnknown: true });
        const { rules, ...verifiedIdToken } = value;
        if (error) {
            (0, cm_libs_context_aware_error_1.throwError)(cm_libs_context_aware_error_1.errors.INVALID_FORMAT, error.message, {
                function: 'verifyIdToken',
                details: error.details,
                text: { input: error.details?.[0]?.context?.peers || error.details?.[0]?.context?.key }
            });
        }
        // Verification via internal function need to keep the rules to return to caller on the response message
        authToken.info.authMetadata ??= {};
        authToken.info.authMetadata.rules = rules;
        const ability = (0, auth_type_1.generateAbilityFromPackedRules)(rules);
        const idToken = {
            ...verifiedIdToken,
            ability
        };
        authToken.type = auth_type_1.AuthTokenType.Basic;
        authToken.grant = true;
        authToken.info.auth = idToken;
        authToken.info.ability = ability;
        authToken.info.requestedBy = idToken.userId;
        authToken.info.requestedByName = idToken.userLogin;
        return authToken;
    }
    static get instance() {
        return this.self || (0, cm_libs_context_aware_error_1.throwError)(cm_libs_context_aware_error_1.errors.NOT_INITIALIZED, 'AuthBasic initialization is required');
    }
}
exports.AuthBasic = AuthBasic;
//# sourceMappingURL=auth-basic.js.map