import { Ability, SubjectRawRule, MongoQuery } from '@casl/ability';
import { AnyObject, ExtractSubjectType, Subject } from '@casl/ability/dist/types/types';
import { PackRule } from '@casl/ability/extra';
import { IdToken } from './auth-id-token';
import { BasicMetadata, BearerMetadata } from './auth-type-verify';
import { AppDomain } from '../type';
export declare enum AuthTokenType {
    Bearer = "Bearer",
    Basic = "Basic"
}
export declare type BaseIdToken = {
    userId: number;
    userLogin: string;
    localeCode: string;
    orgId?: number;
    appDomain?: AppDomain;
    productId?: number;
};
export declare const schemaBaseIdToken: {
    userId: import("joi").NumberSchema;
    userLogin: import("joi").StringSchema;
    localeCode: import("joi").StringSchema;
    orgId: import("joi").NumberSchema;
    appDomain: import("joi").StringSchema;
    productId: import("joi").NumberSchema;
};
export declare type AuthToken = {
    type: AuthTokenType;
    info: AccessInfo;
    grant?: boolean;
};
export declare type AccessInfo = {
    token: string;
    auth?: IdToken;
    authMetadata?: {
        bearer?: BearerMetadata;
        basic?: BasicMetadata;
        rules?: PackRule<any>[];
    };
    headers?: {
        localeCode: string;
    };
    requestedBy?: number;
    requestedByName?: string;
    ability: Ability;
};
export declare type Rule = {
    action: string;
    subject: string;
    fields?: string;
};
export declare type ClaimRule = SubjectRawRule<string, ExtractSubjectType<Subject>, MongoQuery<AnyObject>>;
export declare type AuthDirective = {
    type: AuthTokenType;
    hasAbility?: Rule;
    flag?: boolean;
};
export declare function generateAbility(rules?: ClaimRule[]): Ability<import("@casl/ability").AbilityTuple<string, Subject>, MongoQuery<AnyObject>>;
export declare function generateAbilityFromPackedRules(rules: PackRule<any>[]): Ability<import("@casl/ability").AbilityTuple<string, Subject>, MongoQuery<AnyObject>>;
